glue\_genes.glue\_single\_cell.qt.summarize\_gene\_subset.GeneSummaryListener
=============================================================================

.. currentmodule:: glue_genes.glue_single_cell.qt.summarize_gene_subset

.. autoclass:: GeneSummaryListener

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GeneSummaryListener.__init__
      ~GeneSummaryListener.delete_subset
      ~GeneSummaryListener.notify
      ~GeneSummaryListener.receive_message
      ~GeneSummaryListener.register_to_hub
      ~GeneSummaryListener.set_circular_refs
      ~GeneSummaryListener.unregister
      ~GeneSummaryListener.update_subset
   
   

   
   
   